from ssw_wrapper import StripedSmithWaterman


def local_pairwise_align_ssw(query_sequence,
                             target_sequence,
                             gap_open_penalty=11,
                             gap_extend_penalty=1,
                             match_score=2,
                             mismatch_score=-3):
    ssw = StripedSmithWaterman(query_sequence,
                               gap_open_penalty=gap_open_penalty,
                               gap_extend_penalty=gap_extend_penalty,
                               match_score=match_score,
                               mismatch_score=mismatch_score)
    alignment = ssw(target_sequence)
    return alignment



#!/usr/bin/env python


import numpy as np
from setuptools import find_packages, setup
from setuptools.extension import Extension
from Cython.Build import cythonize


extensions = cythonize([
    Extension("ssw_aligner.ssw_wrapper",
              ["ssw_aligner/ssw_wrapper.pyx",
               "ssw_aligner/_lib/ssw.c"],
              extra_compile_args=['-Wno-error=declaration-after-statement'])
])


setup(name='ssw_aligner',
      version='0.0.6',
      license='MIT',
      description='Python implementation of Striped Smith-Waterman Algorithm',
      long_description='Python implementation of Striped Smith-Waterman Algorithm(one of the local alignment algorithms). Please visit the github page for more details.',
      author="kyu999",
      author_email="kyukokkyou999@gmail.com",
      maintainer="kyu999",
      maintainer_email="kyukokkyou999@gmail.com",
      url='https://github.com/kyu999/ssw_aligner',
      packages=find_packages(),
      ext_modules=extensions,
      include_dirs=[np.get_include()]
)
